==> jc-1.4.0.tar.gz: java/sql/SQLException.h <==
// public class java.sql.SQLException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_sql_SQLException_H_
#define _JC_java_sql_SQLException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_SQLException$object;

// Typedefs
typedef struct _jc_java_sql_SQLException$sub_refs	_jc_java_sql_SQLException$sub_refs;
typedef struct _jc_java_sql_SQLException$sub_nonrefs	_jc_java_sql_SQLException$sub_nonrefs;
typedef struct _jc_java_sql_SQLException$refs	_jc_java_sql_SQLException$refs;
typedef struct _jc_java_sql_SQLException$nonrefs	_jc_java_sql_SQLException$nonrefs;
typedef struct _jc_java_sql_SQLException$object	_jc_java_sql_SQLException$object;

typedef struct _jc_java_sql_SQLException$fields_struct	_jc_java_sql_SQLException$fields_struct;
typedef const struct _jc_java_sql_SQLException$vmethods	_jc_java_sql_SQLException$vmethods;
typedef const struct _jc_java_sql_SQLException$vtable	_jc_java_sql_SQLException$vtable;
typedef const struct _jc_java_sql_SQLException$vtype	_jc_java_sql_SQLException$vtype;

// Class fields structure
struct _jc_java_sql_SQLException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_SQLException$fields_struct _jc_java_sql_SQLException$class_fields;

// Constructors
extern void _jc_java_sql_SQLException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_SQLException$object *);
extern void _jc_java_sql_SQLException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_sql_SQLException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_sql_SQLException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jint _jc_java_sql_SQLException$method$getErrorCode$7590b5393bb67361(_jc_env *, struct _jc_java_sql_SQLException$object *);
extern struct _jc_java_sql_SQLException$object *_jc_java_sql_SQLException$method$getNextException$6eb6ecd7b5654a02(_jc_env *, struct _jc_java_sql_SQLException$object *);
extern struct _jc_java_lang_String$object *_jc_java_sql_SQLException$method$getSQLState$fa8e8675f38f107d(_jc_env *, struct _jc_java_sql_SQLException$object *);
extern void _jc_java_sql_SQLException$method$setNextException$4c7bdf47704eb5a2(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_sql_SQLException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_sql_SQLException$method_info$getErrorCode$7590b5393bb67361;
extern _jc_method _jc_java_sql_SQLException$method_info$getNextException$6eb6ecd7b5654a02;
extern _jc_method _jc_java_sql_SQLException$method_info$getSQLState$fa8e8675f38f107d;
extern _jc_method _jc_java_sql_SQLException$method_info$setNextException$4c7bdf47704eb5a2;

// Virtual methods structure
struct _jc_java_sql_SQLException$vmethods {
	jint	(*getErrorCode$7590b5393bb67361)(_jc_env *, struct _jc_java_sql_SQLException$object *);
	struct _jc_java_sql_SQLException$object	*(*getNextException$6eb6ecd7b5654a02)(_jc_env *, struct _jc_java_sql_SQLException$object *);
	struct _jc_java_lang_String$object	*(*getSQLState$fa8e8675f38f107d)(_jc_env *, struct _jc_java_sql_SQLException$object *);
	void	(*setNextException$4c7bdf47704eb5a2)(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_sql_SQLException$object *);
};

// Vtable
struct _jc_java_sql_SQLException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
};

// Vtype
struct _jc_java_sql_SQLException$vtype {
	_jc_type			type;
	_jc_java_sql_SQLException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLException$sub_refs {
	struct _jc_java_sql_SQLException$object	*next;
	struct _jc_java_lang_String$object	*SQLState;
};

// Reference instance fields (object)
struct _jc_java_sql_SQLException$refs {
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLException$sub_nonrefs {
	jint	vendorCode;
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
};

// Object instance structure
struct _jc_java_sql_SQLException$object {
	_jc_java_sql_SQLException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLException$vtype	*vtype;
	_jc_java_sql_SQLException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLException$vtype _jc_java_sql_SQLException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLException$class_object;

#endif	/* _JC_java_sql_SQLException_H_ */

==> jc-1.4.6.tar.gz: java/sql/SQLException.h <==
// public class java.sql.SQLException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_sql_SQLException_H_
#define _JC_java_sql_SQLException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_SQLException$object;

// Typedefs
typedef struct _jc_java_sql_SQLException$sub_refs	_jc_java_sql_SQLException$sub_refs;
typedef struct _jc_java_sql_SQLException$sub_nonrefs	_jc_java_sql_SQLException$sub_nonrefs;
typedef struct _jc_java_sql_SQLException$refs	_jc_java_sql_SQLException$refs;
typedef struct _jc_java_sql_SQLException$nonrefs	_jc_java_sql_SQLException$nonrefs;
typedef struct _jc_java_sql_SQLException$object	_jc_java_sql_SQLException$object;

typedef struct _jc_java_sql_SQLException$fields_struct	_jc_java_sql_SQLException$fields_struct;
typedef const struct _jc_java_sql_SQLException$vmethods	_jc_java_sql_SQLException$vmethods;
typedef const struct _jc_java_sql_SQLException$vtable	_jc_java_sql_SQLException$vtable;
typedef const struct _jc_java_sql_SQLException$vtype	_jc_java_sql_SQLException$vtype;

// Class fields structure
struct _jc_java_sql_SQLException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_SQLException$fields_struct _jc_java_sql_SQLException$class_fields;

// Constructors
extern void _jc_java_sql_SQLException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_sql_SQLException$method$getErrorCode$7590b5393bb67361(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_sql_SQLException$object *_jc_java_sql_SQLException$method$getNextException$6eb6ecd7b5654a02(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_sql_SQLException$method$getSQLState$fa8e8675f38f107d(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLException$method$setNextException$4c7bdf47704eb5a2(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_sql_SQLException$method_info$getErrorCode$7590b5393bb67361;
extern _jc_method _jc_java_sql_SQLException$method_info$getNextException$6eb6ecd7b5654a02;
extern _jc_method _jc_java_sql_SQLException$method_info$getSQLState$fa8e8675f38f107d;
extern _jc_method _jc_java_sql_SQLException$method_info$setNextException$4c7bdf47704eb5a2;

// Virtual methods structure
struct _jc_java_sql_SQLException$vmethods {
	jint	(*getErrorCode$7590b5393bb67361)(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
	struct _jc_java_sql_SQLException$object	*(*getNextException$6eb6ecd7b5654a02)(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSQLState$fa8e8675f38f107d)(_jc_env *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
	void	(*setNextException$4c7bdf47704eb5a2)(_jc_env *, struct _jc_java_sql_SQLException$object *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_sql_SQLException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
};

// Vtype
struct _jc_java_sql_SQLException$vtype {
	_jc_type			type;
	_jc_java_sql_SQLException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLException$sub_refs {
	struct _jc_java_sql_SQLException$object	*next;
	struct _jc_java_lang_String$object	*SQLState;
};

// Reference instance fields (object)
struct _jc_java_sql_SQLException$refs {
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLException$sub_nonrefs {
	jint	vendorCode;
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
};

// Object instance structure
struct _jc_java_sql_SQLException$object {
	_jc_java_sql_SQLException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLException$vtype	*vtype;
	_jc_java_sql_SQLException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLException$vtype _jc_java_sql_SQLException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLException$class_object;

#endif	/* _JC_java_sql_SQLException_H_ */
